@@ -5,6 +5,7 @@ from django.utils import simplejson
 from python import Serializer as PythonSerializer
 from django.core.serializers.json import Deserializer as JSONDeserializer, \
     DjangoJSONEncoder
+from django.http import HttpResponse
 
 class Serializer(PythonSerializer):
     """
@@ -18,6 +19,7 @@ class Serializer(PythonSerializer):
         self.options.pop('relations', None)
         self.options.pop('extras', None)
         self.options.pop('use_natural_keys', None)
+        self.use_httpresponse=self.options.pop('httpresponse', None)
         simplejson.dump(self.objects, self.stream, cls=DjangoJSONEncoder,
             **self.options)
 
@@ -28,6 +30,11 @@ class Serializer(PythonSerializer):
         """
 
         if callable(getattr(self.stream, 'getvalue', None)):
-            return self.stream.getvalue()
+            value = self.stream.getvalue()
+
+        if self.use_httpresponse:
+            return HttpResponse(value)
+        else:
+            return value
 
 Deserializer = JSONDeserializer
